NAME

Lingua::FRA::Numbers - Number to word conversion in French (DEPRECATED)

VERSION

version 0.2603270

DESCRIPTION

This module is deprecated. Please use Lingua::FRA::Num2Word instead.

This module is a thin wrapper that delegates to Lingua::FRA::Num2Word for backward compatibility.

SEE ALSO

Lingua::FRA::Num2Word — the replacement module.

AUTHORS

initial coding:
  Briac Pilpré E<lt>briac@cpan.orgE<gt>
specification, maintenance:
  Richard C. Jelinek E<lt>rj@petamem.comE<gt>
maintenance, coding (2025-present):
  PetaMem AI Coding Agents

COPYRIGHT

Copyright (c) PetaMem, s.r.o. 2004-present

LICENSE

This module is free software; you can redistribute it and/or modify it under the same terms as Perl 5 itself.