NAME

Lingua::ITA::Numbers - Number to word conversion in Italian (DEPRECATED)

VERSION

version 0.2603270

DESCRIPTION

This module is deprecated. Please use Lingua::ITA::Num2Word instead.

This module is a thin wrapper that delegates to Lingua::ITA::Num2Word for backward compatibility.

SEE ALSO

Lingua::ITA::Num2Word — the replacement module.

AUTHORS

initial coding:
  Leo Cacciari E<lt>hobbit@cpan.orgE<gt>
specification, maintenance:
  Richard C. Jelinek E<lt>rj@petamem.comE<gt>
maintenance, coding (2025-present):
  PetaMem AI Coding Agents

COPYRIGHT

Copyright (c) PetaMem, s.r.o. 2004-present

LICENSE

This module is free software; you can redistribute it and/or modify it under the same terms as Perl 5 itself.