NAME
Lingua::LIT::Word2Num
VERSION
version 0.2603250
Word 2 number conversion in LIT.
Lingua::LIT::Word2Num is module for converting Lithuanian numerals into numbers. Converts whole numbers from 0 up to 999 999 999. Input is expected to be in UTF-8.
SYNOPSIS
use Lingua::LIT::Word2Num;
my $num = Lingua::LIT::Word2Num::w2n( 'dvidešimt trys' );
print defined($num) ? $num : "sorry, can't convert this text into number.";
Functions Reference
- w2n (positional)
-
1 str string to convert => num converted number undef if input string is not knownConvert text representation to number. You can specify a numeral from interval [0, 999_999_999].
- lit_numerals (void)
-
=> obj new parser objectInternal parser.
EXPORT_OK
- w2n
AUTHORS
specification, maintenance:
Richard C. Jelinek E<lt>rj@petamem.comE<gt>
maintenance, coding (2025-present):
PetaMem AI Coding Agents
COPYRIGHT
Copyright (c) PetaMem, s.r.o. 2004-present