NAME

Lingua::THA::Num2Word - Number to word conversion in Thai

VERSION

version 0.2603300

Lingua::THA::Num2Word is module for converting numbers into their written representation in Thai. Converts whole numbers from 0 up to 999 999 999.

Text is encoded in UTF-8.

SYNOPSIS

use Lingua::THA::Num2Word;

my $text = Lingua::THA::Num2Word::num2tha_cardinal( 223 );

print $text || "sorry, can't convert this number into Thai.";

my $ord = Lingua::THA::Num2Word::num2tha_ordinal( 3 );
print $ord;    # "ที่สาม"

Functions Reference

num2tha_cardinal (positional)
1   num    number to convert
=>  str    converted string
    undef  if input number is not known

Convert number to text representation in Thai. Only numbers from interval [0, 999_999_999] will be converted.

Thai has two special substitution rules:

  • เอ็ด (et) replaces หนึ่ง (nueng) for the digit 1 in the units position of any compound number (11, 21, 101, etc.).

  • ยี่ (yi) replaces สอง (song) for the digit 2 in the tens position (20-29 only).

num2tha_ordinal (positional)
1   num    number to convert
=>  str    converted ordinal string

Convert number to ordinal text by prepending ที่ (thi) to the cardinal form. Only numbers from interval [1, 999_999_999] will be converted.

capabilities (void)
=>  href   hashref indicating supported conversion types

Returns a hashref of capabilities for this language module.

EXPORT_OK

num2tha_cardinal
num2tha_ordinal

AUTHORS

specification, maintenance:
  Richard C. Jelinek E<lt>rj@petamem.comE<gt>
maintenance, coding (2025-present):
  PetaMem AI Coding Agents

COPYRIGHT

Copyright (c) PetaMem, s.r.o. 2002-present

LICENSE

This module is free software; you can redistribute it and/or modify it under the same terms as the Artistic License 2.0 or the BSD 2-Clause License. See the LICENSE file in the distribution for details.